@@ -1,4 +1,4 @@
-# (c) Sound Object Logic 2000-2001
+
 
 use strict;
 
@@ -230,18 +230,26 @@ sub where
 
 	my @where_class_id;
 
-	if ($classes->{$class}{stateless})
+	if (0 and $classes->{$class}{stateless})
 	{
 		my @class_ids;
 
-		push @class_ids, $storage->class_id($class) unless $classes->{$class}{abstract};
+		push @class_ids, $storage->class_id($class)
+		    unless $classes->{$class}{abstract};
 
-		$schema->for_each_spec($class,
-							   sub { my $spec = shift; push @class_ids, $storage->class_id($spec) unless $classes->{$spec}{abstract} } );
+		$schema->for_each_spec
+		    ($class,
+		     sub {
+			 my $spec = shift;
+			 push @class_ids, $storage->class_id($spec)
+			     unless $classes->{$spec}{abstract};
+		     } );
 
-		@where_class_id = "t$root.$storage->{class_col} IN (" . join(', ', $storage->_kind_class_ids($class) ) . ')';
 	}
 
+	@where_class_id = "t$root.$storage->{class_col} IN ("
+	    . join(', ', $storage->_kind_class_ids($class) ) . ')';
+
 	my $id = $schema->{sql}{id_col};
 	return (@where_class_id, map { "t@{$_}[1].$id = t$root.$id" } @$tables[1..$#$tables]);
 }
@@ -261,7 +269,13 @@ sub new
 sub and
 {
 	my ($self, $other) = @_;
-	return op($self, 'AND', 10, $other);
+	if ( !ref $other and $other == 1 ) {
+	    $self;
+	} elsif ( !ref $self and $self == 1 ) {
+	    $other;
+	} else {
+	    op($self, 'AND', 10, $other);
+	}
 }
 
 sub and_perhaps
@@ -607,7 +621,7 @@ sub binop
 	}
 	else
 	{
-		$op = $op eq '=' ? 'IS' : $op eq '<>' ? 'IS NOT' : Carp::confess;
+		$op = $op eq '=' ? 'IS' : $op eq '<>' ? 'IS NOT' : Carp::confess("unknown op $op");
 		$arg = 'NULL';
 	}
 
@@ -637,6 +651,20 @@ sub regexp_like
 				   objects => Set::Object->new($self->objects) );
 }
 
+sub match
+{
+       my ($self, $oper, $val) = @_;
+       return Tangram::Filter->new(expr => "$self->{expr} $oper '$val'", tight => 100,
+                                  objects => Set::Object->new($self->objects) );
+}
+
+sub is_null
+{
+       my ($self) = @_;
+       return Tangram::Filter->new(expr => "$self->{expr} IS NULL", tight => 100,
+                                  objects => Set::Object->new($self->objects) );
+}
+
 sub count
 {
 	my ($self, $val) = @_;
@@ -658,7 +686,7 @@ sub in
 	my $storage = $self->{storage};
 
 	my @items;
-	while ( my $item = shift ) {
+	while ( defined(my $item = shift) ) {
 	    if ( ref $item eq "ARRAY" ) {
 		push @items, @$item;
 	    } elsif ( UNIVERSAL::isa($item, "Set::Object") ) {
